==> p01.recipe.setup-0.5.2.zip: p01.recipe.setup-0.5.2/setup.py <==
##############################################################################
#
# Copyright (c) 2010 Projekt01 GmbH and Contributors.
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################
"""
$Id:$
"""

import os
from setuptools import setup, find_packages


def read(*rnames):
    return open(os.path.join(os.path.dirname(__file__), *rnames)).read()

setup(
    name = 'p01.recipe.setup',
    version = '0.5.2',
    author = 'Roger Ineichen and the Zope Community',
    author_email = 'zope-dev@zope.org',
    description = 'Application installation support recipes',
    long_description=(
        read('README.txt')
        + '\n\n' +
        'Detailed Documentation\n'
        '**********************'
        + '\n\n' +
        read('src', 'p01', 'recipe', 'setup', 'README.txt')
        + '\n\n' +
        read('CHANGES.txt')
        ),
    license = 'ZPL 2.1',
    keywords = 'zope3 p01 dev recipe setup installation installer',
    classifiers = [
        'Development Status :: 3 - Alpha',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Zope Public License',
        'Programming Language :: Python',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Topic :: Internet :: WWW/HTTP',
        'Framework :: Zope3'],
    url = 'http://pypi.python.org/pypi/p01.recipe.setup',
    packages = find_packages('src'),
    include_package_data = True,
    package_dir = {'':'src'},
    namespace_packages = ['p01', 'p01.recipe'],
    extras_require = dict(
        test = [
            'zc.lockfile',
            'zope.testing',
            ],
        paste = [
            'Paste',
            'PasteDeploy',
            'PasteScript',
            ],
        supervisor = [
            'supervisor',
            'superlance',
            ],
        ),
    install_requires = [
        'ZConfig >=2.4a5',
        'setuptools',
        'zc.buildout',
        'zc.recipe.egg',
        ],
    entry_points = {
        'zc.buildout': [
             'cmd = p01.recipe.setup.cmd:CMDRecipe',
             'cmmi = p01.recipe.setup.cmmi:CMMIRecipe',
             'copy = p01.recipe.setup.copy:COPYRecipe',
             'download = p01.recipe.setup.download:DownloadRecipe',
             'mkdir = p01.recipe.setup.mkdir:MKDirRecipe',
             'mkfile = p01.recipe.setup.mkfile:MKFileRecipe',
             'paste = p01.recipe.setup.paste:PasteServeSetup',
             'supervisor = p01.recipe.setup.supervisor:SupervisorRecipe',
             'script = p01.recipe.setup.script:ScriptRecipe',
             'template = p01.recipe.setup.template:TemplateRecipe',
         ]
    },
)

==> p01.recipe.setup-0.6.0.zip: p01.recipe.setup-0.6.0/setup.py <==
##############################################################################
#
# Copyright (c) 2010 Projekt01 GmbH and Contributors.
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################
"""
$Id:$
"""

import os
from setuptools import setup, find_packages


def read(*rnames):
    return open(os.path.join(os.path.dirname(__file__), *rnames)).read()

setup(
    name = 'p01.recipe.setup',
    version = '0.6.0',
    author = 'Roger Ineichen and the Zope Community',
    author_email = 'zope-dev@zope.org',
    description = 'Application installation support recipes',
    long_description=(
        read('README.txt')
        + '\n\n' +
        'Detailed Documentation\n'
        '**********************'
        + '\n\n' +
        read('src', 'p01', 'recipe', 'setup', 'README.txt')
        + '\n\n' +
        read('CHANGES.txt')
        ),
    license = 'ZPL 2.1',
    keywords = 'zope3 p01 dev recipe setup installation installer',
    classifiers = [
        'Development Status :: 3 - Alpha',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Zope Public License',
        'Programming Language :: Python',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Topic :: Internet :: WWW/HTTP',
        'Framework :: Zope3'],
    url = 'http://pypi.python.org/pypi/p01.recipe.setup',
    packages = find_packages('src'),
    include_package_data = True,
    package_dir = {'':'src'},
    namespace_packages = ['p01', 'p01.recipe'],
    extras_require = dict(
        test = [
            'zc.lockfile',
            'zope.testing',
            ],
        paste = [
            'Paste',
            'PasteDeploy',
            'PasteScript',
            ],
        supervisor = [
            'supervisor',
            'superlance',
            ],
        ),
    install_requires = [
        'ZConfig >=2.4a5',
        'setuptools',
        'zc.buildout',
        'zc.recipe.egg',
        ],
    entry_points = {
        'zc.buildout': [
             'cmd = p01.recipe.setup.cmd:CMDRecipe',
             'cmmi = p01.recipe.setup.cmmi:CMMIRecipe',
             'copy = p01.recipe.setup.copy:COPYRecipe',
             'download = p01.recipe.setup.download:DownloadRecipe',
             'mkdir = p01.recipe.setup.mkdir:MKDirRecipe',
             'mkfile = p01.recipe.setup.mkfile:MKFileRecipe',
             'paste = p01.recipe.setup.paste:PasteServeSetup',
             'supervisor = p01.recipe.setup.supervisor:SupervisorRecipe',
             'script = p01.recipe.setup.script:ScriptRecipe',
             'scripts = p01.recipe.setup.script:ScriptsRecipe',
             'template = p01.recipe.setup.template:TemplateRecipe',
             'ctags = p01.recipe.setup.ctags:CTagsRecipe',
         ],
        'console_scripts': [
            'ctags = p01.recipe.setup.ctags:ctags',
        ]
    },
    zip_safe = False,
)
